/*  CACHE MEMORY  */

#include <math.h>
#include <stdio.h>
#include <malloc.h>
#include "revxml.typ"
#include "revxml.h"

#include "cm.h"
#include "make_win.h"
#define FREAD_BIN_PLUS		"rb+"
#define FWRITE_BIN_PLUS		"wb+"


cm_type_p cm_cache_p;
boolean Error_detected;
long Cache_PS;
my_int Cache_BS;
extern FILE *logfile;  /* used for the trace file */


char pbuffer[1024];

/* #define DEBUG */

#ifdef DEBUG
/* =============================== showcache ============================================
	 Purpose: For debugging purposes; output the blocknrs in CM-positions (!!! still useful ?)
	 Parameters
	 input: pointer to cache (cm_cache_p)
	 output: order in which the info should be shown
	 input/output:
	 Global variables:
	 Algorithm:
	 Revisions done:
	 Revisions to be done: !!! Remove parameter 'cm_type_p cache' (= always cm_cache_p)
	 ---------------------------------------------------------------------------------------- */
void showcache(cache, type)
cm_type_p cache;
char type;
{
	my_int loper;

	fprintf(tracefile, "[cache inhoud]", 1); 
	switch (type) 
	{
		case 1:	/* op cache-volgorde */
			for (loper=0; loper<cache->buf.bufsize; loper++)
			{  
				fprintf(tracefile, " %ld ",cache->buf.adblocks_p[loper].blocknumber);
			}
			break;
		default: /* Oldest first */
			loper=cache->buf.oldest;
			while (loper != cache->buf.youngest)
			{ 
				fprintf(tracefile, " %ld ",cache->buf.adblocks_p[loper].blocknumber);
				loper = cache->buf.adblocks_p[loper].younger;
			}
			if (cache->buf.oldest!=cache->buf.youngest)
			/* niet lege buffer, dus youngest moet nog geprint worden */
			{
				fprintf(tracefile, " %ld ", cache->buf.adblocks_p[cache->buf.youngest].blocknumber);
			}  
	}
}
#endif

/* =========================== racces_endposition =========================================
	 Purpose: Return the end byteposition of a given file (= filesize + sizeof(pos_type))
	 Parameters
		 input: filehandle
		 output: end byteposition of filehandle
		 input/output:
	 Global variables:
	 Algorithm: Use standard functions fseek followed by ftell to determine the end position
	 Revisions done:
	 Revisions to be done:
	 ---------------------------------------------------------------------------------------- */
long racces_endposition(fil)
FILE *fil;
{
#ifdef DEBUG
	long result;
#endif

	if (fseek(fil, 0L, SEEK_END)) 
	{
		if (fil == NULL)
		{
			/* showerror("racces_endposition invoked with uninitialized fileptr"); == 3-1-2001 */
		}
		else
		{
			/* showerror("unidentified error at racces_endposition"); == 3-1-2001 */
		}
		/* go_to_rest(1);  3-1-2001 */
	}

#ifdef DEBUG
	result = ftell(fil);
	if (result<(long)(sizeof(pos_type)))
	{
		/* Er is eerst een lengte-positie weggeschreven */
		fprintf(tracefile, "fseek failed.", 1); 
		Error_detected = true; 
		return 0;
	}
	return(result);
#else
	return(ftell(fil));
#endif
}

/* ============================== racces_seek ============================================
	 Purpose: Position the filepointer of a given file to a certain byte position
	 Parameters
	 input: filehandle, position
	 output:
	 input/output:
	 Global variables:
	 Algorithm: Use standard function fseek to position the file pointer
	 Revisions done:
	 Revisions to be done:
	 ---------------------------------------------------------------------------------------- */
void racces_seek(fil, position)
FILE *fil;
long position;
{
	if (fseek(fil, position+(long)sizeof(pos_type), SEEK_SET))
	{
		my_int debug_point = 0;
		debug_point = 0;
		 
		if (fil == NULL)
		{
			/* showerror("racces_seek invoked with uninitialized fileptr"); 3-1-2001 */
		}
		else
		{
			/* showerror("unidentified error at racces_seek"); 3-1-2001 */
		}
		/* go_to_rest(1); 3-1-2001 */
	}
}

/* =========================== get_block_from_file ========================================
	 Purpose: Swap block from file to memory. The block has to exist
	 Parameters
		 input: pointer to cache (should be cm_cache_p), blocknr
		 output:
		 input/output: pointer to a to-be-filled memory page
	 Global variables:
	 Algorithm:
		 - if the required block lies beyond the end-of-filescope then return a dummy block initialized
				with zeroes, and exit.
		 - move filepointer to position of required block in file
		 - determine how many physical pages should be read (= memory pagesize / 512)
		 - read the required number of pages into the to-be-filled memory page
	 Revisions done:
	 Revisions to be done:
	 ---------------------------------------------------------------------------------------- */
void get_block_from_file(cm_p, blocknr, elem_p)
cm_type_p cm_p;
long blocknr;
page_type_p elem_p;
{  
	long nr_of_physical_pages_to_be_read;
	long j;
	long end_block;
	void *temp;		 /* Tijdelijke pointer naar te schrijven gebied */
	long pagesize; /* Tijdelijke variabele bespaart 3 geheugen aanroepen per keer */

	/*get_block_from_file*/
	pagesize = cm_p->buf.pagesize;
	nr_of_physical_pages_to_be_read = (my_int)(pagesize >> 9);
	/* pagesize is een veelvoud van NR_OF_BYTES_IN_PHYSICAL_DISC_PAGE, dus een integer * 512 */
	end_block = (racces_endposition(cm_p->fil)-(long)sizeof(pos_type)) / pagesize;
	if (end_block < blocknr)
	{
#ifdef DEBUG
		fprintf(tracefile, "Reading beyond end of file for blocknr : %ld.", blocknr);
		fprintf(tracefile, "              eind blocknr : %ld.", end_block);
		showcache(cm_p, CACHE_SHOW);
#endif
		/* vul blok met 0-waarden */
		for (j = 0L; j < pagesize; (*elem_p)[j++] = 0);
	}
	else
	{ 
		size_t aantalpaginas;
		racces_seek(cm_p->fil,(long)blocknr*pagesize);
		/* filepointer geplaatst op byteoffset in file */
		aantalpaginas = 0;
		temp = *elem_p;
		for (j = 0; j < nr_of_physical_pages_to_be_read; j++)
		{ 
			aantalpaginas += fread(temp,													 /* Hier komt de data in */
				NR_OF_BYTES_IN_PHYSICAL_DISC_PAGE, /* blokgrootte */
				1,																 /* aantal te lezen blokken */
				cm_p->fil);												 /* filenaam */
			temp = (void *)((long)temp + NR_OF_BYTES_IN_PHYSICAL_DISC_PAGE);
		}
		if (aantalpaginas == 0)
		{
			/* error; put breakpoint here */
			j = j;
		}
	}
}

/* =========================== put_block_to_file =========================================
	 Purpose: Swap block from memory to file. 
		 If beyond eof, the file will be extended
		 Comment. In principle, a cache memory can be addressed at random. If a block has to be
		 added beyond the eof position a gap may originate. Some OS's (like the Mac OS) do allow only
		 for the concatenation to a file. Therefore, we close the gap by the insertion of dummy blocks
	 Parameters
		 input: pointer to cache (should be cm_cache_p), blocknr, pointer to to-be-swapped memory page
		 output:
		 input/output:
	 Global variables:
	 Algorithm:
		 - if the required block lies beyond the end-of-filescope then insert dummy blocks to close
			 the gap
		 - move filepointer to position of required block in file
		 - write the memory page to the cache file
	 Revisions done:
	 Revisions to be done:
	 ---------------------------------------------------------------------------------------- */
void put_block_to_file(cm_p, blocknr, elem_p)
cm_type_p cm_p;
long  blocknr;
page_type_p elem_p;
{
	long j;
	long b, end_blocknr; 
	size_t aantalpaginas;
	long nr_of_physical_pages_to_be_written;
	char temp_pagina[NR_OF_BYTES_IN_PHYSICAL_DISC_PAGE];
	long pagesize;	/* temporary variabele */
	void *temp_ptr;	/* temporary pointer to elem_p */

	j = racces_endposition(cm_p->fil)-(long)sizeof(pos_type);
	/* j aangepast voor eerste positie */
	if (j < 0L) 
	{
		fprintf(logfile, "Bad file handle in put_block_to_file.", 1);
		Error_detected = true; 
		return; 
	}
	pagesize = cm_p->buf.pagesize;
	end_blocknr = j / pagesize;	/* get the block number of the end of the file */
	nr_of_physical_pages_to_be_written = pagesize >> 9;
	if (blocknr > end_blocknr)	/* the block to be added is beyond eof */
	{
		for (j=0; j < NR_OF_BYTES_IN_PHYSICAL_DISC_PAGE; temp_pagina[j++] = 0);
		fseek(cm_p->fil, 0L, SEEK_END);	/* filepointer op het eind */
		aantalpaginas=0L;
		for (b = 0L; b < blocknr-end_blocknr; b++)
		{
			/* ==== to be updated: may be done in one fwrite ========= */
			for (j = 0L; j < nr_of_physical_pages_to_be_written; j++)
			{
				aantalpaginas += fwrite(&temp_pagina, NR_OF_BYTES_IN_PHYSICAL_DISC_PAGE, 1, cm_p->fil);
			}
		}
		if (aantalpaginas == 0)
		{
			/* error; put breakpoint here */
			j = j;
		}

		/* 0-pagina is used as fill-material. */
#ifdef DEBUG
		fprintf(tracefile, "Vulmateriaal toegevoegd aan de file van %ld tot %ld.", end_blocknr,blocknr);
		fprintf(tracefile, "Er zijn %ld discpagina's weggeschreven.", aantalpaginas);
#endif
	}
	racces_seek(cm_p->fil,blocknr*cm_p->buf.pagesize);
	temp_ptr = *elem_p;

	/* ==== to be updated: may be done in one fwrite ========= */
	aantalpaginas=0L;
	for (j=0L; j<nr_of_physical_pages_to_be_written; j++)
	{
		aantalpaginas += fwrite(temp_ptr,NR_OF_BYTES_IN_PHYSICAL_DISC_PAGE,1,cm_p->fil);
		/* schrijf echte blok */
		temp_ptr = (void *)((long)temp_ptr+NR_OF_BYTES_IN_PHYSICAL_DISC_PAGE);
	}
			if (aantalpaginas == 0)
		{
			/* error; put breakpoint here */
			j = j;
		}

}

/* =========================== incmbuffer =========================================
	 Purpose: Locate a block in cache memory; if not present the least recent
	 used block is swapped out and the required block is read in
	 Parameters
	 input: pointer to cache (should be cm_cache_p), required blocknumber within cache file
	 output:
	 input/output: blocknumber within buffer
	 Global variables:
	 Algorithm:
	 - locate the required blocknumber by searching memory buffer
	 - if found
		- update administration to reflect that the required blocknumber has recently been 
	 accessed
	 - if not found
		- if there is room in the buffer for one or more new blocks
			- if the buffer is empty then initialize the buffer
				- update buffer administration to reflect the addition of a new block
			- if the buffer is full
				- swap out the oldest block (the block can be discarded if it hasn't been modified)
				- update administration to mark the next oldest block
				- read the required blocknumber from file
				- update administration's 'youngest' info
	 Revisions done:
	 Revisions to be done:
	 ---------------------------------------------------------------------------------------- */
void incmbuffer(cm_p, number, buffer_position)
cm_type_p cm_p;
long number;						 /* required blocknumber within cm_p^.fil */
long *buffer_position; /* returned blocknumber within buffer */
{
	boolean present;
	my_int  i;
	int iend;

	present = false;
	iend = cm_p->buf.bvulling - 1;
	/* total number of pages used in the buffer; count starts at 0 */

#ifdef DEBUG
	fprintf(tracefile, "Processing cache :", 1);
	showcache(cm_p,CACHE_SHOW);	/* print cache-lijst */
	if (iend < -1) 
	{
		fprintf(tracefile, "De vulling is %ld blokken.",cm_p->buf.bvulling);
		Error_detected = true;
		return; 
	}
	if (iend == -1)
	{
		fprintf(tracefile, "%s", "(leeg)");
	}
	if (iend == cm_p->buf.bufsize - 1) 
	{
		fprintf(tracefile, "%s", "(vol)");
	}
#endif

	i = 0;
	while ((i <= iend) && !present)	/* locate the required block number; could be faster */
	{
		if (cm_p->buf.adblocks_p[i]->blocknumber == number)
		{ 
			*buffer_position = i;
			present = true;
#ifdef DEBUG
			fprintf(tracefile, "(hit)  %ld = c%ld", number, i);
#endif
		}
		else
		{
			i++;
		}
	}
	if (present) /* administration of usage */
	{
		if ((*buffer_position == cm_p->buf.oldest) &&
			(cm_p->buf.oldest != cm_p->buf.youngest))
		{ 
			cm_p->buf.oldest = cm_p->buf.adblocks_p[*buffer_position]->younger;
			cm_p->buf.adblocks_p[cm_p->buf.oldest]->older = 0;
		}
		else if (*buffer_position != cm_p->buf.youngest)
		{
			cm_p->buf.adblocks_p[cm_p->buf.adblocks_p[*buffer_position]->older]->younger = 
				cm_p->buf.adblocks_p[*buffer_position]->younger;
			cm_p->buf.adblocks_p[cm_p->buf.adblocks_p[*buffer_position]->younger]->older = 
				cm_p->buf.adblocks_p[*buffer_position]->older;
		}
	}
	else /* not present */
	{ 
		if (cm_p->buf.bvulling < cm_p->buf.bufsize)	/* there is room in the buffer for one or more new pages */
		{
			if (cm_p->buf.bvulling == 0) /* there is no page at all in the buffer; the file must be empty */
			{ 
				cm_p->buf.adblocks_p[0]->younger = 0; /* initialize the administration for the buffer */
				cm_p->buf.adblocks_p[0]->older = 0;
				cm_p->buf.oldest = 0;
				cm_p->buf.youngest = 0;
			}
			cm_p->buf.bvulling++;											 /* new number of pages in the buffer */
			*buffer_position = cm_p->buf.bvulling - 1; /* number of the new page in the buffer; count starts at 0 */
		}
		else /* bvulling >= bufsize */
		{
			/* buffer is full; swap out the oldest page */
			*buffer_position = cm_p->buf.oldest;
			if (cm_p->buf.adblocks_p[cm_p->buf.oldest]->modified) /* but only of the page has been modified */
			{
				put_block_to_file(cm_p, cm_p->buf.adblocks_p[cm_p->buf.oldest]->blocknumber, cm_p->buf.blocks_p[cm_p->buf.oldest]);
			}

			/* the oldest page has been written out */
#ifdef DEBUG
			fprintf(tracefile, "blok %ld <- c%d",cm_p->buf.adblocks_p[*buffer_position].blocknumber,*buffer_position);
			showcache(cm_p,CACHE_SHOW);
#endif
			cm_p->buf.oldest = cm_p->buf.adblocks_p[cm_p->buf.oldest]->younger; /* mark the next oldest page */
			cm_p->buf.adblocks_p[cm_p->buf.oldest]->older = 0;
		}
		get_block_from_file(cm_p, number, cm_p->buf.blocks_p[*buffer_position]);
		/* the new page has been read in */
		cm_p->buf.adblocks_p[*buffer_position]->modified = false; /* mark the new page as not modified */
#ifdef DEBUG
		fprintf(tracefile, "blok %ld -> c%d.",number, *buffer_position); 
		showcache(cm_p, CACHE_SHOW);
#endif
	}
	cm_p->buf.adblocks_p[*buffer_position]->blocknumber = number; /* remember the blocknumber for this page in the buffer */
																																	 /* update youngest-lijst */
	if (*buffer_position != cm_p->buf.youngest)
	{ 
		cm_p->buf.adblocks_p[*buffer_position]->younger = 0;
		cm_p->buf.adblocks_p[*buffer_position]->older = cm_p->buf.youngest;
		cm_p->buf.adblocks_p[cm_p->buf.youngest]->younger = *buffer_position;
		cm_p->buf.youngest = *buffer_position;
	}
}


/* ================================ pos_to_ptr =============================================
	 Purpose: Translate a position in the external file to a physical ptr into the internal buffer
	 Parameters
		 input:
		 output:
		 input/output: virtual pointer containing a position in the external file
	 Global variables: cm_cache_p
	 Algorithm:
		 - if bufslot of the vp equals -1
			 - move the required block of the file into memory
		 - if bufslot does not equal -1
			 - if the blocknumber positioned at index bufslot in the administration equals the blocknumber
				 of the fileposition contained in the vp
				 - move the required block of the file into memory 
	 Revisions done:
	 Revisions to be done:
	 ---------------------------------------------------------------------------------------- */
void pos_to_ptr(vp)
virtual_ptr_type  *vp;
/* translate a position in the external file to a physical ptr into the internal buffer */
{ 
	if (vp->bufslot == - 1)
	{  
		incmbuffer(vp->cm_p, vp->filepos.blocknr, &vp->bufslot);
		vp->rampos = &((*(vp->cm_p->buf.blocks_p)[vp->bufslot])[vp->filepos.pos_in_block]);
	}
	else if (vp->cm_p->buf.adblocks_p[vp->bufslot]->blocknumber != vp->filepos.blocknr)
	/* Let op compiler mag de tweede actie niet uitvoeren als de eerste waar is */
	{  
		incmbuffer(vp->cm_p, vp->filepos.blocknr, &vp->bufslot);
		vp->rampos = &((*(vp->cm_p->buf.blocks_p)[vp->bufslot])[vp->filepos.pos_in_block]);
	};
} /*pos_to_ptr*/


/* ============================= alloc_cm_record ===========================================
	 Purpose: Allocate a record of a specified size in cache memory
	 Parameters
		 input: pointer to cache (should be cm_cache_p), length of record (= 'size')
		 output:
		 input/output: virtual pointer containing the location of the record in memory
	 Global variables:
	 Algorithm:
		 - if there is room in the first_free block of the cache
			 - add 'size' to first_free.pos_in_block
		 - if there is not enough room in the first_free block
			 - increase first_free.blocknr by 1 and assign 'size' to first_free.pos_in_block
			 - assign first_free to vp.filepos and update cache administration
	 Revisions done:
	 Revisions to be done:
	 ---------------------------------------------------------------------------------------- */
boolean alloc_cm_record(cm_p, size, vp)
cm_type_p cm_p;
long size;
virtual_ptr_type *vp;
{ 
	long position_record_in_block; /* startposition of the new record in its block */

	/* in case of memory segmentation problems: increase "size" to multiple of 16 or 32 */
	/* size = ... */

	if ((cm_p->buf.first_free.pos_in_block + size) <= cm_p->buf.pagesize)
	{
		position_record_in_block = cm_p->buf.first_free.pos_in_block;
		cm_p->buf.first_free.pos_in_block = cm_p->buf.first_free.pos_in_block + size;
		/* new free position */
		/* there seems to be a bug in MPW when positioning in cm_str; we allocate 1 byte more */
		cm_p->buf.first_free.pos_in_block++;
	}
	else
	{
		if (size > cm_p->buf.pagesize)
			return false;
		cm_p->buf.first_free.blocknr++;						/* new free block */
		position_record_in_block = 0L;
		cm_p->buf.first_free.pos_in_block = size;	/* new free position */
	}
	vp->cm_p = cm_p;
	vp->bufslot = - 1;
	vp->filepos.blocknr = cm_p->buf.first_free.blocknr;
	vp->filepos.pos_in_block = position_record_in_block;
	pos_to_ptr(vp);
	cm_p->buf.adblocks_p[vp->bufslot]->modified = true; /* mark block as modified */
	return true;
}	/* alloc_cm_record */

/* =========================== cmflush =========================================
	 Purpose: Flush all modified blocks
	 Parameters
	 input: pointer to cache
	 output:
	 input/output:
	 Global variables:
	 Algorithm:
	 Revisions done:
	 Revisions to be done:
	 ---------------------------------------------------------------------------------------- */
void cmflush(cm_p)
cm_type_p cm_p;
{
	long bufferloper;

	/* write out the first free position */
	fseek(cm_p->fil, 0L, SEEK_SET);	/* start file */
	fwrite(&cm_p->buf.first_free, sizeof(pos_type), 1, cm_p->fil);

	bufferloper = 0L;
	while (bufferloper < cm_p->buf.bvulling)
	{ 
		put_block_to_file(cm_p, cm_p->buf.adblocks_p[cm_p->buf.oldest]->blocknumber,
			cm_p->buf.blocks_p[cm_p->buf.oldest]);
		cm_p->buf.oldest = cm_p->buf.adblocks_p[cm_p->buf.oldest]->younger;
		bufferloper++;
	}
}

/* ================================ open_cm ==============================================
	 Purpose: Initializes a cache memory, and opens an external file
	 Parameters
		 input: pointer to cache (should be cm_cache_p), filename, pagesize, buffersize
		 output: 	return_code: 1 if memory allocation fails, else 0
							true if the external file does not yet exist, false otherwise
		 input/output: 
	 Global variables:
	 Algorithm:
	 - if the file is empty
		 - open external file
		 - set first_free to position {0,8}
		 - write first_free to position {0,0} of the external file
	 - if the file is not empty
		 - read first_free from position {0,0} of the external file
	 Revisions done:
	 Revisions to be done:
	 ---------------------------------------------------------------------------------------- */
boolean open_cm(cm_type_p cm_p, char *filename, long pagsize, my_int buffersize, long *return_code)
{   
	my_int   i;
	boolean init_file; /* true als file geinitieerd moet worden */ 

	*return_code = 0;
	/* initialize the administration for cm */
	init_file = false;
	cm_p->buf.pagesize = pagsize << 9;
	cm_p->buf.bufsize = buffersize;
	cm_p->buf.bvulling = 0;
	cm_p->buf.oldest = 0;
	cm_p->buf.youngest = 0;
	cm_p->buf.blocks_p = malloc(cm_p->buf.bufsize * 4);	/* allocate array of pointers */
	cm_p->buf.adblocks_p = malloc(cm_p->buf.bufsize * 4);	/* allocate array of pointers */
	if ( (cm_p->buf.blocks_p == NULL) || (cm_p->buf.adblocks_p == NULL) )
	{
		*return_code = 1;
		return false;
	} 

	for (i = 0; i < cm_p->buf.bufsize; i++)
	{
		cm_p->buf.blocks_p[i] = (page_type_p)malloc((long)pagsize * sizeof(page_type));
		cm_p->buf.adblocks_p[i] = (cmblokadtype_p)malloc(sizeof(cmblokadtype));
		if (cm_p->buf.blocks_p[i] == NULL)
		{
			*return_code = 1;
			return false;
		} 
	}
	strcpy(cm_p->filename, filename);
	cm_p->fil = fopen(filename, FREAD_BIN_PLUS); /* open the associated file */
	if ((cm_p->fil) == NULL)
	{
		cm_p->fil = fopen(filename, FWRITE_BIN_PLUS);
		init_file = true;
		if (cm_p->fil == NULL)
		{  
			sprintf(pbuffer, "File %s could not be opened for output.", filename);
			Error_detected = true; 
			return false;
		}
		/* init the first_free at the first position after the fixed */
		cm_p->buf.first_free.blocknr = 0; /* 0 is used as a special condition */
		cm_p->buf.first_free.pos_in_block = sizeof(pos_type);
		fseek(cm_p->fil, 0L,SEEK_SET);
		fwrite(&cm_p->buf.first_free, sizeof(pos_type), 1, cm_p->fil);
		/* Schrijf first_free naar de file */
	}
	else /* the file is not empty: read the fixed information at the start of the file (which is the first
					free position) */
	{	
		fseek(cm_p->fil, 0L, SEEK_SET);	/* plaats pointer op start file */
		fread(&(cm_p->buf.first_free), sizeof(pos_type), 1, cm_p->fil);
#ifdef DEBUG
		fprintf(tracefile, "%s", "Just read header-info into first_free.");
		fprintf(tracefile, "Block: %ld  Position: %ld.", cm_p->buf.first_free.blocknr, cm_p->buf.first_free.pos_in_block);
#endif
	}
	return(init_file);
}

/* ================================ close_cm =============================================
	 Purpose: closes a cache memory
	 Parameters
		 input: pointer to cache
		 output:
		 input/output: 
	 Global variables:
	 Algorithm:
		 - write first_free to position {0,0} of the external file
		 - flush buffers
		 - close the external file
	 Revisions done:
	 Revisions to be done:
	 ---------------------------------------------------------------------------------------- */
void close_cm(cm_p)
cm_type_p cm_p;
{ 
	my_int  i;

	/* flushes the modified buffers */
	cmflush(cm_p);
	/* frees the buffers */
	for (i = 0; i < cm_p->buf.bufsize; i++)
	{
		free(cm_p->buf.blocks_p[i]);
	}
	free(cm_p->buf.blocks_p);
	free(cm_p->buf.adblocks_p);
	fclose(cm_p->fil);
}
