#ifndef CM_H
#define CM_H

/* PCM 2001.03.12: 
   The following typedefs are assumed to be done by the calling file.
   Repeating them here can give rise to compiler errors.

   typedef short my_int; 
   typedef unsigned short my_unsigned_int; 
   typedef unsigned char boolean;
   
   NOTE by PCM: currently, these definitions are done in RevXml.h. Must check once
   if it is possible to do the definitions here and let other modules use them.
   The current approach has the impression of being 'upside-down'.
*/


typedef char string80[81];
typedef char string132[133];
typedef char string255[255];


#define OLDEST_FIRST 0
#define CACHE_ARRAY  1
#define CACHE_SHOW OLDEST_FIRST
/* Geeft de manier aan waarop de cache-lijst wordt afgedrukt */
/* 
	maximum number of pages in a buffer of a cache memory; this number is only relevant for
	the arrays for administration; the actual number of pages is allocated dynamically upon
	request of the user of the cache memory 
*/
#define NR_OF_BYTES_IN_PHYSICAL_DISC_PAGE  512
/* 
	Vanaf nu is dit getal in het programma gecodeerd. Dit houdt in dat
	in plaats van de langzame deling een snelle shift wordt uitgevoerd.
	Deze waarde kan dus niet meer veranderd worden zonder het hele programma
	na te zoeken.
*/

typedef struct
{
	  long blocknr; 			/* number of logical block */
	  long pos_in_block; 		/* position within logical block */
} pos_type;

typedef pos_type *pos_type_p;
typedef char page_type[NR_OF_BYTES_IN_PHYSICAL_DISC_PAGE];
typedef page_type *page_type_p;
typedef struct  				/* administration for each block in the CM buffer */
{ 
	long blocknumber; 			/* number of logical block */
  	long younger, older; 		/* within the chain of usage history */
  	boolean modified;  			/* true if the page has been modified */
} cmblokadtype;

typedef cmblokadtype *cmblokadtype_p;

typedef struct
{ 
	pos_type	first_free; 		/* cm position of the first free record */
	long			pagesize;   			/* size of a page in this cm */
	long		bufsize;    			/* number of pages in the buffer for this cm */
	            							/* Geen unsigned, omdat -1 gebruikt wordt als speciale code */
	long 				oldest, 
								youngest, 
								bvulling; 			/* #blocks already used in the buffer */
	cmblokadtype_p  *adblocks_p; /* administration for each block */
	page_type_p		*blocks_p;		/*ptr*/ /* the pages in the buffer themselves */
} cmbuftype;

typedef struct  				/* a cache memory consists of : */
{  
	cmbuftype  buf; 			/* a buffer, with administration */
	FILE     *fil; 			/* together with its associated file */
	string80	 filename;	/* corresponding filename, inclusive path */ 
} cm_type;

typedef cm_type *cm_type_p;

typedef  struct        			/* combines the file- and the ram-ptr */
{ 
	cm_type_p cm_p;   			/* the actual cm for this virtual ptr */ 
	pos_type filepos;  			/* the file ptr */
	void  *rampos; 				/* the physical ptr in the buffer */
	long bufslot;       		/* the condition: cm_p^.buf.bufad.adblocks[bufslot].blocknumber = filepos.blocknr 
									holds at the creation of this virtual ptr; this condition may always be 
									checked in order to verify that the page is not swapped out */
	char dummy[2];
} virtual_ptr_type;

typedef struct  				/* a result record contains the result of the search of an element in a list */
{ 
	boolean tested, 			/* true if the search was executed */
	found; 						/* true if the search succeeded*/
	virtual_ptr_type vp; 		/* - if found: the position of the located element - if not found: position 
									of the last element in the list (in order to facilitate the adding of a 
									new element); the position will contain 0's iff the list was empty */
} result_type;

typedef result_type *result_type_p;

extern cm_type_p cm_cache_p;
extern boolean Error_detected;
extern long Cache_PS;
extern my_int Cache_BS;


void incmbuffer(
#ifndef NO_PROTO
	cm_type_p cm_p, 
	long number,  				/* required blocknumber within cm_p^.fil */
	long *buffer_position 	/* returned blocknumber within buffer */
#endif
); 

void init_position(
#ifndef NO_PROTO
	pos_type_p position
#endif
);

void racces_seek(
#ifndef NO_PROTO
	FILE *fil, 
	long position
#endif
);

boolean position_is_zero(
#ifndef NO_PROTO
	pos_type position
#endif
);

boolean alloc_cm_record(
#ifndef NO_PROTO
	cm_type_p cm_p,
	long size,
	virtual_ptr_type *vp
#endif
);

void get_block_from_file(
#ifndef NO_PROTO
	cm_type_p cm_p, 
	long blocknr, 
	page_type_p elem_p
#endif
);

void put_block_to_file(
#ifndef NO_PROTO
	cm_type_p cm_p,
	long  blocknr,
	page_type_p elem_p
#endif
);

void output_triggers(
#ifndef NO_PROTO
	my_unsigned_int p
#endif
);

void pos_to_ptr(
#ifndef NO_PROTO
	virtual_ptr_type  *vp
#endif
);

boolean open_cm(
#ifndef NO_PROTO
	cm_type_p cm_p, 
	char *filename, 
	long pagsize, 
	my_int buffersize,
	long *return_code
#endif
);

void cmflush(
#ifndef NO_PROTO
	cm_type_p cm_p
#endif
);

void close_cm(
#ifndef NO_PROTO
	cm_type_p cm_p
#endif
);

my_unsigned_int *get_object(
#ifndef NO_PROTO
	my_unsigned_int i
#endif
);

void remove_file(
#ifndef NO_PROTO
	char *filename
#endif
);

void open_store(
#ifndef NO_PROTO
	long PS, 
	my_int BS,
	long *return_code
#endif
);

void exit_store(
#ifndef NO_PROTO
	boolean must_remove
#endif
);

#endif /* CM_H */
