/*  MAKE_WIN: MAKES OUTPUT WINDOWS */

/*  #define STANDALONE_MAKEWIN */
/* A standalone WinMain function is provided at the end of this file. */

#if defined(WINDOWS) || defined(WIN32)

//#include "platform.h"
//#include "ls_error.h"

#include <windows.h>
#include <stdio.h>
#include <string.h>
#include <malloc.h>
#include <stdlib.h>     

#include "make_res.h"
#include "make_win.h"

#define MAXFILENAME 10
HANDLE  hInst;								/* instance of main window */
HANDLE  hAccTable;						/* handle to accelerator table */
HWND  hMainWnd = (HWND) NULL;	/* handle to main window */
HWND  hMaxWnd = (HWND) NULL;
HLOCAL  font_ptr;
HFONT   hfont, hfontOld;
PLOGFONT plf;
HDC   hdc;

struct windef_t
{
	boolean Notified_of_error;
	HWND  hwnd;
	int   line_count;
	HMENU   parent_id;
	HMENU   child_id;
	LPSTR   caption;
} windef[MAX_NR_OPENWINDOWS];

int parent_index = 0;
int child_index = 0;

/* new variables for common dialogs */

OPENFILENAME ofn;        
/* file type filters */      
char szFilterSpec[128] = "Text Files (*.TXT)\0*.TXT\0All Files (*.*)\0*.*\0";
char szFileName[MAXFILENAME];
char szFileTitle[MAXFILENAME];
/* char szBaseWindowTitle[] = "OUTPUT Window"; -- title is now a parameter -- SI 96.03.08 */
char szWindowTitle[80];
OFSTRUCT of;



/****************************************************************************
	 
	 FUNCTION: InitApplication(HANDLE)
	 
	 PURPOSE: Initializes window data and registers window class
	 
	 ****************************************************************************/

boolean InitApplication(hInstance)
HANDLE hInstance;
{
	WNDCLASS  wc;

	wc.style = 0;	/* NULL; SI  96.01.31 */
	wc.lpfnWndProc = MainWndProc;
	wc.cbClsExtra = 0;
	wc.cbWndExtra = 0;
	wc.hInstance = hInstance;
	wc.hIcon = LoadIcon((HINSTANCE) NULL, IDI_APPLICATION);
	wc.hCursor = LoadCursor((HINSTANCE) NULL, IDC_ARROW);
	wc.hbrBackground = GetStockObject(WHITE_BRUSH);
	wc.lpszMenuName =  "OUTPUTMENU";
	wc.lpszClassName = "OutputWClass";

	if (!RegisterClass(&wc))
		return FALSE;

	wc.style = 0;	/* NULL; -- SI 96.01.31 */
	wc.lpfnWndProc = MainWndProc;
	wc.cbClsExtra = 0;
	wc.cbWndExtra = 0;
	wc.hInstance = hInstance;
	wc.hIcon = LoadIcon((HINSTANCE) NULL, IDI_ASTERISK);
	wc.hCursor = LoadCursor((HINSTANCE) NULL, IDC_ARROW);
	wc.hbrBackground = GetStockObject(WHITE_BRUSH);
	wc.lpszMenuName =  NULL;
	wc.lpszClassName = "EditWClass";

	return ((boolean)RegisterClass(&wc));
}


/****************************************************************************
	 
	 FUNCTION:  InitChildInstance(int, HMENU, HMENU, LPSTR, int, int, int, int)
	 
	 PURPOSE:  Saves instance handle and creates child window
	 
	 ****************************************************************************/

boolean far InitChildInstance(win_id, title, xco, yco, width, height)
int win_id;
LPSTR title;
int xco;
int yco;
int width;
int height;
{
	/* Create a new parent window (a child of hMainWnd) */

	HWND hParent;
	HWND hChild;
	RECT rc;

	windef[win_id].parent_id = (HMENU) (300 + parent_index++);
	windef[win_id].child_id = (HMENU) (350 + child_index++);
	windef[win_id].line_count = 0;
	windef[win_id].Notified_of_error = FALSE;
	windef[win_id].caption = title;

	if (xco == -1)
	{
		GetClientRect(hMainWnd, &rc);
		xco = yco = 0;
		width = (rc.right-rc.left);
		height = (rc.bottom-rc.top);    
	}

	hParent = CreateWindow(
		"EditWClass",
		title,
		WS_VISIBLE | WS_OVERLAPPEDWINDOW | 
		WS_CHILD | WS_CLIPSIBLINGS,
		xco,
		yco,
		width,
		height,
		hMainWnd,
		windef[win_id].parent_id,
		hInst,
		NULL
		);

	if (!hParent)
		return (FALSE);

	/* Create a child window (multiline edit control) */

	GetClientRect(hParent, &rc);

	hChild = CreateWindow(
		"Edit",
		NULL,
		WS_CHILD |
		WS_VISIBLE | ES_MULTILINE |
		WS_VSCROLL | WS_HSCROLL |
		ES_AUTOHSCROLL | ES_AUTOVSCROLL,
		0,
		0,
		(rc.right-rc.left),
		(rc.bottom-rc.top),
		hParent,
		windef[win_id].child_id,
		hInst,
		NULL
		);

	if (!hChild) 
	{
		DestroyWindow(hMainWnd);
		/* return (NULL); -- SI 96.01.31 */
		return (FALSE);
	}

	windef[win_id].hwnd = hChild;

	SendMessage(hChild, EM_LIMITTEXT, 0, 0L);
	SendMessage(hChild, WM_SETFONT, (WPARAM)hfont, 0);
	UpdateWindow(hParent);

	return TRUE;
}


/****************************************************************************
	 
	 FUNCTION:  InitMainInstance(HANDLE, int)
	 
	 PURPOSE:  Saves instance handle and creates main window
	 
	 ****************************************************************************/

boolean InitMainInstance(hInstance, nCmdShow, windowTitle, xco, yco, width, height)
HANDLE hInstance;
int nCmdShow;   
char *windowTitle;
int xco;
int yco;
int width;
int height;
{
	hInst = hInstance;
	hAccTable = LoadAccelerators(hInst, "OUTPUTACC");
	hMainWnd = CreateWindow(
		"OutputWClass",
		windowTitle,
		WS_OVERLAPPEDWINDOW | WS_VISIBLE,
		xco,
		yco,
		width,
		height,
		(HWND) NULL,
		(HMENU) NULL,
		(HINSTANCE) hInstance,
		NULL
		);

	if (!hMainWnd)
		return (FALSE);

	ShowWindow(hMainWnd, nCmdShow);
	UpdateWindow(hMainWnd);
	return (TRUE);
}


long far pascal  MainWndProc(hWnd, message, wParam, lParam)
HWND hWnd;
UINT message;
WPARAM wParam;
LPARAM lParam;
{
	FARPROC lpProcAbout;
	MINMAXINFO far* lpmmi;
	RECT rc;

	switch (message)
	{
		case WM_GETMINMAXINFO:
			if ((hWnd != hMainWnd) && (IsWindow(hMainWnd)))
			{
				lpmmi = (MINMAXINFO FAR*) lParam;
				GetClientRect(hMainWnd, &rc);
				lpmmi->ptMaxSize.x = (rc.right-rc.left) + 8;
				lpmmi->ptMaxSize.y = (rc.bottom-rc.top) + 8;
			}
			break;

		case WM_COMMAND:
			if ((wParam >= 300) && (wParam <= 399))
			{
				if (HIWORD (lParam) == EN_ERRSPACE) 
				{
					MessageBox 
						(
						GetFocus(),
						"Out of memory.",
						"No can do",
						MB_ICONHAND | MB_OK
						);
					DestroyWindow(hWnd);
					/* SvdB: dit moet nog veranderd worden in wat vriendelijkers; het
						 window moet nog openblijven om de uitvoer te kunnen zien */    
				}
			}

			switch (wParam) 
			{
				case IDM_ABOUT:
					lpProcAbout = MakeProcInstance(About, hInst);
					DialogBox(hInst, "AboutBox", hWnd, lpProcAbout);
					FreeProcInstance(lpProcAbout);
					break;

				case IDM_OPEN:
					/*
						 if (Ask_Filename(hWnd))
						 {
						 lstrcpy(szWindowTitle, szBaseWindowTitle);
						 lstrcat(szWindowTitle, " - ");
						 lstrcat(szWindowTitle, szFileTitle);
						 SetWindowText(hMainWnd, szWindowTitle);
						 }
						 */
					MessageBox (
						hWnd,
						"Command not implemented",
						"No can do",
						MB_ICONASTERISK | MB_OK);
					break;

				case IDM_SAVEAS:
					/*                  
						 if (!GetSaveFileName ((LPOPENFILENAME)&ofn))
						 return FALSE;
						 
						 lstrcpy(szWindowTitle, szBaseWindowTitle);
						 lstrcat(szWindowTitle, " - ");
						 lstrcat(szWindowTitle, szFileTitle);
						 SetWindowText(hMainWnd, szWindowTitle);
						 */
					MessageBox (
						hWnd,
						"Command not implemented",
						"No can do",
						MB_ICONASTERISK | MB_OK);
					break;

				case IDM_NEW:
				case IDM_SAVE:
				case IDM_PRINT:
					MessageBox (
						GetFocus(),
						"Command not implemented",
						"No can do",
						MB_ICONASTERISK | MB_OK);
					break;

				case IDM_EXIT:
					DestroyWindow(hMainWnd);
					break;

				/* edit menu commands */

				case IDM_UNDO:
				case IDM_CUT:
				case IDM_COPY:
				case IDM_PASTE:
				case IDM_CLEAR:
					MessageBox (
						GetFocus(),
						"Command not implemented",
						"No can do",
						MB_ICONASTERISK | MB_OK);
					break;
			}
			break;

		/*
			 case WM_CLOSE:
			 if (MessageBox(hWnd, "Are you sure you want to exit?", "WM_CLOSE",
			 MB_ICONQUESTION | MB_OKCANCEL) == IDOK)
			 DestroyWindow(hWnd);
			 return 0L;
			 */
		case WM_SIZE:
			if (hWnd != hMainWnd)
				if (wParam == SIZE_MAXIMIZED)
					hMaxWnd = hWnd;
			if (hWnd == hMainWnd && hMaxWnd != (HWND) NULL && IsZoomed(hMaxWnd))
			{
				GetClientRect(hMainWnd, &rc);
				MoveWindow(hMaxWnd, -4, -4, (rc.right-rc.left) + 8, (rc.bottom-rc.top) + 8, TRUE);
			}
			if ((hWnd != hMainWnd) && IsWindow(GetTopWindow(hWnd)))
				MoveWindow(GetTopWindow(hWnd), 0, 0, LOWORD(lParam), HIWORD(lParam), TRUE);
			break;

		case WM_DESTROY:
			if (hWnd == hMainWnd)
			{
				hdc = GetDC(hMainWnd);
				hfontOld = SelectObject(hdc, hfont);
				LocalUnlock(font_ptr);
				LocalFree(font_ptr);
				SelectObject(hdc, hfontOld);
				DeleteObject(hfont);
				ReleaseDC(hMainWnd, hdc);
				PostQuitMessage(0);
				exit(0); 
			}
	}

	return (DefWindowProc(hWnd, message, wParam, lParam));
}


/****************************************************************************
	 
	 FUNCTION: About(HWND, unsigned, WORD, LONG)
	 
	 PURPOSE:  Processes messages for "About" dialog box
	 
	 MESSAGES:
	 
	 WM_INITDIALOG - initialize dialog box
	 WM_COMMAND    - Input received
	 
	 ****************************************************************************/

BOOL far pascal About(hDlg, message, wParam, lParam)
HWND hDlg;
unsigned message;
WORD wParam;
LONG lParam;
{
	switch (message) 
	{
		case WM_INITDIALOG:
			return (TRUE);

		case WM_COMMAND:
			if (wParam == IDOK || wParam == IDCANCEL) 
			{
				EndDialog(hDlg, TRUE);
				return (TRUE);
			}
			break;
	}
	return (FALSE);
}


/***************************************************************************/


void far showerror(char *text)
{
	MessageBox(hMainWnd, (LPSTR)text, (LPSTR)"Fatal ERROR:", MB_OK);
}


void win_showerror(int win_id, int err_no)
{
	if (IsWindow(hMainWnd))
		switch(err_no)
		{
			case 1:
				MessageBox (
					hMainWnd,
					"Illegal window id - subsequent wwrite calls will be discarded.",
					windef[win_id].caption,
					MB_ICONASTERISK | MB_OK);
		}

	windef[win_id].Notified_of_error = TRUE;
}


void far flush_wwrite_buffer()
{
	MSG msg;

	while (PeekMessage(&msg, (HWND) NULL, 0, 0, PM_REMOVE) && (msg.message != WM_QUIT)) 
	{
		TranslateMessage(&msg);
		DispatchMessage(&msg);
	}
}

boolean far wwrite(char *str, int win_id)
{
	WPARAM clines, line_index;
	HWND outputwnd = windef[win_id].hwnd;

	flush_wwrite_buffer();

	if (!IsWindow(outputwnd))
	{
		if (!windef[win_id].Notified_of_error) 
		{
			win_showerror(win_id, 1);
		}
		return FALSE;
	}

	/*  if (strlen(str) > 130)
		 strcpy(str, "The number of characters in this line exceeds 130. Please investigate this matter ASAP!");
		 */  
	/* SvdB: het geheugen dat gealloceerd wordt met EM_REPLACESEL wordt volgens Bounds-Checker
		 niet meer vrijgegeven. Dit zaakje vereist nog nader onderzoek. */

	if (++windef[win_id].line_count > MAX_NR_LINES)
	{
		line_index = (WPARAM)SendMessage(outputwnd, EM_LINEINDEX, 1, 0);
		/*   SendMessage (outputwnd, EM_SETSEL, 1, MAKELPARAM(0, line_index)); GvdS 4-6-96 */
		SendMessage (outputwnd, EM_SETSEL, 0, line_index);
		SendMessage (outputwnd, WM_SETREDRAW, 0, 0L);
		SendMessage (outputwnd, EM_REPLACESEL, 0, (LPARAM)(LPSTR)"");
		SendMessage (outputwnd, WM_SETREDRAW, 1, 0L);
	}

	clines = (WPARAM)SendMessage(outputwnd, EM_GETLINECOUNT, 0, 0);
	line_index = (WPARAM)SendMessage(outputwnd, EM_LINEINDEX, clines - 1, 0);
	/*  SendMessage (outputwnd, EM_SETSEL, 1, MAKELPARAM(line_index, line_index)); GvdS 4-6-96, change for WIN32 */
	SendMessage (outputwnd, EM_SETSEL, line_index, line_index);	/* last position, in order to append */
	SendMessage (outputwnd, EM_REPLACESEL, 0, (LPARAM)(LPSTR)str);
	SendMessage (outputwnd, EM_REPLACESEL, 0, (LPARAM)(LPSTR)"\r\n");

	return TRUE;
}


boolean far woverwrite(char *str, int win_id)
{
	WPARAM clines, line_index1, line_index2;
	HWND outputwnd = windef[win_id].hwnd;

	flush_wwrite_buffer();

	if (!IsWindow(outputwnd))
	{
		if (!windef[win_id].Notified_of_error)
			win_showerror(win_id, 1);
		return FALSE;
	}

	if (strlen(str) > 1024)
		strcpy(str, "The number of characters in this line exceeds 1024...");

	/* SvdB: het geheugen dat gealloceerd wordt met EM_REPLACESEL wordt volgens Bounds-Checker
		 niet meer vrijgegeven. Dit zaakje vereist nog nader onderzoek. */

	clines = (WPARAM)SendMessage(outputwnd, EM_GETLINECOUNT, 0, 0);
	if (clines > 1)
	{
		line_index1 = (WPARAM)SendMessage(outputwnd, EM_LINEINDEX, clines - 2, 0);
		line_index2 = (WPARAM)SendMessage(outputwnd, EM_LINEINDEX, clines - 1, 0);
		/*   SendMessage (outputwnd, EM_SETSEL, 1, MAKELPARAM(line_index1, line_index2)); GvdS 4-6-96, change for WIN32 */
		SendMessage (outputwnd, EM_SETSEL, line_index1, line_index2);
		SendMessage (outputwnd, EM_REPLACESEL, 0, (LPARAM)(LPSTR)str);
		SendMessage (outputwnd, EM_REPLACESEL, 0, (LPARAM)(LPSTR)"\r\n");  
	}
	else
	{
		return wwrite(str, win_id);
	}

	return TRUE;
}
#endif

#ifdef DOS
void far showerror(char *text)
{
	printf(text);
	printf("\r\n");
}


boolean far wwrite(char *str, int win_id)
{
	printf(str);
	printf("\r\n");
	return TRUE;
} 


boolean far woverwrite(char *str, int win_id)
{
	printf(str);
	printf("\r\n");
	return TRUE;
} 
#endif


/*
	 -----------------------------------------------------------------------------
	 InitMainWindow
	 
	 Remembers main instance, creates main window, initialises timer, etc.
	 -----------------------------------------------------------------------------
	 */

#if defined(WINDOWS) || defined(WIN32)
boolean far InitMainWindow(hInstance, hPrevInstance, nCmdShow, windowTitle, xco, yco, width, height)
HANDLE hInstance;
HANDLE hPrevInstance;
int nCmdShow;
char *windowTitle;
int xco;
int yco;
int width;
int height;
{
	if (!hPrevInstance)
		if (!InitApplication(hInstance))
			return FALSE;

	if (!InitMainInstance(hInstance, nCmdShow, windowTitle, xco, yco, width, height))
		return FALSE;

	/* fill in non-variant fields of OPENFILENAME struct. */
	ofn.lStructSize           = sizeof(OPENFILENAME);
	ofn.hwndOwner             = hMainWnd;
	ofn.lpstrFilter           = szFilterSpec;
	ofn.lpstrCustomFilter     = NULL;
	ofn.nMaxCustFilter        = 0;
	ofn.nFilterIndex          = 1;
	ofn.lpstrFile             = szFileName;
	ofn.nMaxFile              = MAXFILENAME;
	ofn.lpstrInitialDir       = NULL;
	ofn.lpstrFileTitle        = szFileTitle;
	ofn.nMaxFileTitle         = MAXFILENAME;
	ofn.lpstrTitle            = NULL;
	ofn.lpstrDefExt           = "TXT";
	ofn.Flags                 = 0;

	/* create common font style */
	font_ptr = LocalAlloc(LMEM_MOVEABLE | LMEM_ZEROINIT, sizeof(LOGFONT));
	plf = (PLOGFONT)LocalLock(font_ptr);
	plf->lfHeight = 14;
	plf->lfWidth = 8;
	plf->lfWeight = FW_NORMAL;
	plf->lfPitchAndFamily = FIXED_PITCH | FF_MODERN;
	strcpy(plf->lfFaceName, "Courier");
	hfont = CreateFontIndirect(plf);

	return TRUE;
}


boolean far Main_Loop()
{            
	MSG msg;

	if (!IsWindow(hMainWnd))
		return TRUE;

	/* while (GetMessage(&msg, NULL, NULL, NULL)) -- SI 96.01.31 */
	while (GetMessage(&msg, (HWND) NULL, 0, 0)) 
	{
		/* Only translate message if it is not an accelerator message */
		if (!TranslateAccelerator(hMainWnd, hAccTable, &msg))
		{
			TranslateMessage(&msg);
			DispatchMessage(&msg);
		}
	}

	return msg.wParam;
}

/***************************************************************************/


#ifdef STANDALONE_MAKEWIN
boolean pascal WinMain(hInstance, hPrevInstance, lpCmdLine, nCmdShow)
HANDLE hInstance;
HANDLE hPrevInstance;
LPSTR lpCmdLine;
int nCmdShow;
{
	int i;
	char temp1[10];
	char temp2[10];

	if (!InitMainWindow(hInstance, hPrevInstance, nCmdShow, 20, 20, 620, 400))
		return FALSE;
	if (!InitChildInstance(2, "Output window #3", 400, 40, 200, 200))
		return FALSE;
	if (!InitChildInstance(1, "Output window #2", 80, 30, 300, 300))
		return FALSE;
	if (!InitChildInstance(0, "Output window #1", 10, 10, 200, 200))
		return FALSE;

	/*  CALL TO ENGINE: */
	for (i = 0; i <= 100; i++)
	{
		wwrite("Testing", 0);
		wwrite("Testing", 1);
		wwrite("Testing", 2);
		strcpy(temp2, "Line ");
		_itoa(i, temp1, 10);
		strcat(temp2, temp1);
		wwrite(temp2, 0);
		wwrite(temp2, 1);
		wwrite(temp2, 2);
	}

	return Main_Loop();
} 

#endif        

/********************************************************************/

#if 0

boolean Read_File(LPSTR Filename, HWND Requesting_Window)
{
	WORD   wLength;
	HANDLE hT;
	LPSTR  lpB;
	int    FileHandle;

	FileHandle = _lopen (Filename, READ_WRITE);
	if (FileHandle < 0)
		return FALSE;
	wLength = (WORD)_llseek (FileHandle, 0L, 2);
	_llseek (FileHandle, 0L, 0);

	/* Attempt to reallocate the edit control's buffer to the file size */
	hT = (HANDLE)SendMessage (Requesting_Window, EM_GETHANDLE, 0, 0L);
	if (LocalReAlloc(hT, wLength+1, LHND) == 0) 
	{
		/* Couldn't reallocate to new size -- error */
		_lclose (FileHandle);
		return FALSE;
	}

	/* read the file into the buffer */
	if (wLength != _lread (FileHandle, (lpB = (LPSTR)LocalLock (hT)), wLength))
	{
		_lclose (FileHandle);
		return FALSE;
	}  

	/* Zero terminate the edit buffer */
	lpB[wLength] = 0;
	LocalUnlock (hT);
	SendMessage (Requesting_Window, EM_SETHANDLE, hT, 0L);

	_lclose (FileHandle);
	return TRUE;
}


boolean Ask_Filename(HWND Requesting_Window)
{
	char    szFile[128];
	OPENFILENAME of;

	lstrcpy(szFile, "*.TXT");

	memset(&of, '\0', sizeof(OPENFILENAME));

	of.lStructSize        = sizeof(OPENFILENAME);
	of.hwndOwner          = Requesting_Window;
	of.lpstrFilter        = szFilterSpec;
	of.lpstrCustomFilter  = NULL;
	of.nMaxCustFilter     = 0;
	of.nFilterIndex       = 1;
	of.lpstrFile          = (LPSTR)szFile;
	of.nMaxFile           = MAXFILENAME;
	of.lpstrInitialDir    = NULL;
	of.lpstrTitle         = NULL;
	of.Flags              = OFN_HIDEREADONLY | OFN_FILEMUSTEXIST;
	of.lpstrDefExt        = NULL;

	if(!GetOpenFileName(&of))
		return FALSE;

	return Read_File(of.lpstrFile, Requesting_Window);
}

#endif

#endif
