/* Sentinel.c */

#include <windows.h>
#include <string.h>
#include <time.h>
#include "lserv.h"   /* header file for SentinelLM    */

#include "vintlstr.h"

#define min(a,b) (((a) < (b)) ? (a) : (b))
#define max(a,b) (((a) > (b)) ? (a) : (b))

long FAR PASCAL WndProc (HWND, UINT, UINT, LONG) ;

/* SentinelLM variables and defines */

#define FEATURE "99"
#define VERSION ""

#define BOUNCE_DEMO_NAME VL10N_BNC_LBL_DEMO_NAME_01_STR
#define INFINITE_PERIOD  -1

static char szAppName [512];
LS_HANDLE   handle_p = 0;

static long lastUpdateTime;
static long updateInterval;

void sentinel_start()
{
	LS_STATUS_CODE rc;
	VLSfeatureInfo finfo;

	lastUpdateTime = time(NULL);
	if (lastUpdateTime <= 0) 
	{
		 MessageBox (hwnd, VL10N_BNC_ERR_TMCALL_FAIL_STR, szAppName, 
								MB_OK | MB_ICONEXCLAMATION);
		 PostQuitMessage (0) ;
		 return 0;
	}

/* ====== added 21-1-2002 ======== */

#define TRACE_api
#ifdef TRACE_api
		VLSsetTraceLevel(VLS_TRACE_ALL);
#endif
/* ====== end added 21-1-2002 ======== */

   /* Prepare to use SentinelLM */
   if (VLS_INITIALIZE ())
	 {
			MessageBox (hwnd, VL10N_BNC_ERR_INIT_FAIL_STR, szAppName, 
									MB_OK | MB_ICONEXCLAMATION);
			PostQuitMessage (0) ;
			return 0;
   }     

   VLSdisableLocalRenewal(); /* SentinelLM API call for key renewal */
   VLSsetServerPort(5093);
   VLSdisableAutoTimer( 0, VLS_OFF );

   /* Request key from SentinelLM license manager */
   rc = VLS_REQUEST(FEATURE, VERSION, &handle_p);
   if (rc != LS_SUCCESS)
	 {
       /* Cleanup after using SentinelLM */
       VLS_CLEANUP ();
       PostQuitMessage (0) ;
       return 0;
   }
   /* Fill the size parameter of featureInfo struct.
    * Query may not get complete data otherwise.    
    */
   finfo.structSz = sizeof(finfo); 
	 rc = VLSgetFeatureInfo(FEATURE, VERSION, 0, NULL, &finfo);
   if (rc != LS_SUCCESS) 
	 {
     /* Cleanup after using SentinelLM */
     VLS_CLEANUP ();
     PostQuitMessage (0) ;
     return 0;
   }
   if(finfo.key_life_time != VLS_NO_EXPIRATION)
		 updateInterval = (long)(0.8 * finfo.key_life_time);
   else
		 updateInterval = INFINITE_PERIOD; 

   VLSerrorHandle(VLS_OFF);  
   if (!SetTimer (hwnd, 1, 50, NULL)) 
	 {
     if (handle_p) VLS_RELEASE (handle_p);
     VLS_CLEANUP ();
     MessageBox (hwnd, VL10N_BNC_ERR_TOO_CLKSTM_STR,
                  szAppName, MB_ICONEXCLAMATION | MB_OK) ;
     return FALSE ;
   }

   /*
    * Get the name of the server we are talking to so we can display
    * it in the title bar.
    */
   if (VLSgetServerNameFromHandle(handle_p, (char LSFAR) serverName,
              sizeof(serverName)) != LS_SUCCESS)
     /* Its not fatal. Just say we don't know. */
     strcpy(serverName, "UNKNOWN");
   
} /* End of sentinel_start() */

     

void sentinel_end()
{
	static HANDLE hBitmap ;
	LS_STATUS_CODE rc;
	char          ErrorMsg[1024];
	char          serverName[MAXLEN];
	long          timeNow;

  /* Release SentinelLM key */
  if (handle_p) VLS_RELEASE (handle_p);

  /* Cleanup after using SentinelLM */
  VLS_CLEANUP ();

  PostQuitMessage (0) ;
  return;
}
