/*  Inclusion file 'Sgd_trac.inc'
		Contains tracing functions for RevXml.c
*/

/* ===================== print_tree_trace   =========================
Purpose:          prints the pointers of the nodes of a text tree;
                  to aid the interpretation of the printout of
                  the function print_internal_structure
Parameters:       
  input:          top_node        : node at the top of the (sub)tree
                  top_barposition : initial indent
Global variables: 
Algorithm:        analogous to print_tree
----------------------------------------------------------------------*/
void print_tree_trace(node_type_p top_node, long top_barposition)
{
  long  i, j;
  node_type_p current_node;

  if (top_node->former == NULL)
    fprintf(tracefile, "-%d", (long)top_node);
  else
    fprintf(tracefile, "%d", (long)top_node); 
      
  if ( (!top_node->leaf) && (top_node->u.f.down_start != NULL) )
  {
    fprintf(tracefile, " --");
    top_barposition++;
    barposition[top_barposition] = len_pointers + 4;
    current_node = top_node->u.f.down_start;
    while (current_node != NULL)
    {
      if (current_node->next != NULL)
          barsigns[top_barposition] = '|';
      else
          barsigns[top_barposition] = ' ';
      print_tree_trace(current_node, top_barposition);
      current_node = current_node->next;
      if (current_node != NULL)
      {
        for (j = 1; j <= len_pointers; j++)
          fprintf(tracefile, " ");
        for (i = 1; i <= top_barposition; i++)
        {
          for (j = 1; j <= barposition[i] - 1; j++)
            fprintf(tracefile, " ");
          fprintf(tracefile, "%c", barsigns[i]);
        };
        fprintf(tracefile, "\n");
        for (j = 1; j <= len_pointers; j++)
          fprintf(tracefile, " ");
        for (i = 1; i <= top_barposition - 1; i++)
        {
          for (j = 1; j <= barposition[i] - 1; j++)
            fprintf(tracefile, " ");
          fprintf(tracefile, "%c", barsigns[i]);
        };
        fprintf(tracefile, "    ");
      };
    };
  }
  else
    fprintf(tracefile, "\n");
} /*of print_tree_trace */

/* =====================  print_node_trace  =========================
Purpose:          prints the information in the nodes of a text tree;
                  for debugging purposes
Parameters:       
  input:          top_node  : node at the top of the (sub)tree
  output:         
  input/output:   
Global variables: 
Algorithm:        
    - the sequence of printing of the nodes is the same as in print_tree
    - the function is called recursively
    - printed are:
      - diff_markers
      - crs_in_original
      - node_compared_with
      - compressed d
      - the pointers to surrounding nodes
      - the pointers to the text
----------------------------------------------------------------------*/
void print_node_trace(node_type_p top_node)
{
  long i, m, n, ca_index;
  node_type_p current_node;
  diff_marker_type_p diff_marker_p;
  crs_in_original_type_p crs_in_original_p;
  /* compressed_from_type_p compressed_from_p; */
  compared_with_type_p compared_with_p;
	my_int bufslot;
	short nr_diff_of_attrs;
	compared_with_buffer_type_p compared_with_buffer_p;
	diff_of_attrs_type *diff_of_attrs;
	long attributes_length;
	char *compressed_array_p;

  fprintf(tracefile, "================ print for node %d\n", 
                                            (long)top_node);
  fprintf(tracefile, " tag = %s  tagcode = %d\n", top_node->tag, 
                                          top_node->tagcode);
  fprintf(tracefile, 
  " empty = %d  leaf = %d  start_of_tagstring = %d  end_of_tagstring = %d\n", 
      top_node->empty, top_node->leaf, top_node->start_of_tagstring, 
      top_node->end_of_tagstring);

  fprintf(tracefile, "%d attributes\n", top_node->number_of_attributes);
  for (i = 0; 
			 i < top_node->number_of_attributes; 
			 i++)
    { fprintf(tracefile, 
          "%d attr_name = %d  attr_value = %d  sequence = %d\n",
          i, 
          top_node->attributes->attr_info[i].attr_name, 
          top_node->attributes->attr_info[i].attr_value, 
          top_node->attributes->attr_info[i].sequence);
    };

  fprintf(tracefile, " diff_markers = \n");
  diff_marker_p = top_node->start_diff_marker;
  while (diff_marker_p != NULL)
  { 
		fprintf(tracefile, "  at %ld :",
                              (long)diff_marker_p);
		fprintf(tracefile, "  position_a = %d",
                              diff_marker_p->position_char_a);
		fprintf(tracefile, "  position_b = %d",
                              diff_marker_p->position_char_b);
    fprintf(tracefile, "  kind_of_diff = ");
    switch (diff_marker_p->kind_of_diff)
    { case diff_open_a_has_more:
        fprintf(tracefile, "%s\n", 
              tag_open_for_a_has_more);
        break;
      case diff_close_a_has_more:
        fprintf(tracefile, "%s\n", 
              tag_close_for_a_has_more);
        break;
      case diff_open_b_has_more:
        fprintf(tracefile, "%s\n", 
              tag_open_for_b_has_more);
        break;
      case diff_close_b_has_more:
        fprintf(tracefile, "%s\n", 
              tag_close_for_b_has_more);
        break;
    };  /* end switch */
    diff_marker_p = diff_marker_p->next;
  };

  fprintf(tracefile, " crs_in_original = \n");
  crs_in_original_p = top_node->start_crs_in_original;
  while (crs_in_original_p != NULL)
  {
    fprintf(tracefile, "     position = %d\n",
            crs_in_original_p->position);
    crs_in_original_p = crs_in_original_p->next;
  };
    
  fprintf(tracefile, " compared_with = \n");
  compared_with_p = filepos_to_ptr(&(top_node->compared_with), &bufslot);
  while (compared_with_p != NULL)
  { 
		fprintf(tracefile, "     node_compared_with = %d\n",
            (long)compared_with_p->node_compared_with);
    fprintf(tracefile, 
            "     result_of_comparison = %d\n",
            compared_with_p->result_of_comparison);

/*  == maybe removed ==========  
    fprintf(tracefile, "     nr_diff_of_attrs = %d   ",
            compared_with_p->nr_diff_of_attrs);
    for ( i = 0; 
					i < compared_with_p->nr_diff_of_attrs; 
					i++)

      fprintf(tracefile, "  %d ", 
              compared_with_p->diff_of_attrs->diffattr[i]);
    fprintf(tracefile, "\n");
    
    fprintf(tracefile, "     compressed_from : ");
    compressed_from_p = compared_with_p->start_of_compressed_from_p;
    while (compressed_from_p != NULL)
    { 
			fprintf(tracefile, "  %d ", compressed_from_p->kind_of_from);
      compressed_from_p = compressed_from_p->next;
    };
			==== later: take care of cache memory; done, follows hereafter: 
	*/
 
		nr_diff_of_attrs = compared_with_p->nr_diff_of_attrs;
    fprintf(tracefile, "     nr_diff_of_attrs = %d:   ", nr_diff_of_attrs);

		compared_with_buffer_p = (compared_with_buffer_type_p)compared_with_p;
		diff_of_attrs = (diff_of_attrs_type_p)(&compared_with_buffer_p->buffer[sizeof(compared_with_type)]);
		for (i = 0; i < nr_diff_of_attrs; i++)
			fprintf(tracefile, "  %d ", diff_of_attrs->diffattr[i]);

    fprintf(tracefile, "\n     compressed_from : ");
 
 		attributes_length = compared_with_p->nr_diff_of_attrs * sizeof(short);

		compressed_array_p = (char *)
							(&(compared_with_buffer_p->buffer[sizeof(compared_with_type) + attributes_length]));
		ca_index = 0;
		while (compressed_array_p[ca_index] != '0')
    { 
			fprintf(tracefile, "  %c ", compressed_array_p[ca_index]);
			ca_index++;
    };

    fprintf(tracefile, "\n");
                    
    if (top_node->leaf)
    { 
			fprintf(tracefile, "     st_of_diff_a = %d",
              compared_with_p->start_of_difference_a);
      fprintf(tracefile, "  st_of_diff_b = %d",
              compared_with_p->start_of_difference_b);
      fprintf(tracefile, "  end_of_diff_a = %d",
              compared_with_p->end_of_difference_a);
      fprintf(tracefile, "  end_of_diff_b = %d\n",
              compared_with_p->end_of_difference_b);
    };
    /* de volgende statement is overbodig geworden */
    if (top_node->leaf != 0)
    { 
			m = compared_with_p->end_of_difference_a -
       compared_with_p->start_of_difference_a + 1;
      n = compared_with_p->end_of_difference_b -
       compared_with_p->start_of_difference_b + 1;
    }
    else
    { 
			m = (compared_with_p->node_compared_with)->
       u.f.nr_of_nodes_down;
      n = top_node->u.f.nr_of_nodes_down;
    };
    compared_with_p = filepos_to_ptr(&(compared_with_p->next), &bufslot);
  };
  if (top_node->leaf)
  { 
		fprintf(tracefile, " start_of_text = %d\n",
     top_node->u.t.start_of_text);
    fprintf(tracefile, " end_of_text = %d\n",
     top_node->u.t.end_of_text);
    fprintf(tracefile, " length_of_text = %d\n",
     top_node->u.t.length_of_text);
    if (atomic_unit_of_text != rev_chars)
    { 
			fprintf(tracefile, 
              "     length_of_hash_coded_text = %d   ",
              top_node->u.t.length_of_hash_coded_text);
      for (i = 0; 
					 i < top_node->u.t.length_of_hash_coded_text; 
					 i++)
        fprintf(tracefile, "  %d ", (long)top_node->u.t.hashcode_text[i]);
      fprintf(tracefile, "\n");
    };
  }
  else
  { fprintf(tracefile, 
     " sequence_nr_of_node = %d  down_start = %d  down_end = %d  nr_of_nodes_down = %d\n",
     (long)top_node->sequence_nr_of_node, (long)top_node->u.f.down_start, 
		 (long)top_node->u.f.down_end, (long)top_node->u.f.nr_of_nodes_down);
  };

  if ( (!top_node->leaf) && (top_node->u.f.down_start != NULL) )
  {
    current_node = top_node->u.f.down_start;
    while (current_node != NULL)
    {
      print_node_trace(current_node);
      current_node = current_node->next;
    };
  }
  else
	{
      fprintf(tracefile, "\n");
	}
} /*of print_node_trace */

/* =====================  print_internal_structure  =================
Purpose:          prints to the tracefile
                  1. the pointers of the nodes of a text tree
                  2. the contents of each node
Parameters:       
  input:          top_node        : node at the top of the (sub)tree
Algorithm:        
----------------------------------------------------------------------*/
void print_internal_structure(node_type_p top_node)
{ /*print_internal_structure*/
  fprintf(tracefile, "\n");
  fprintf(tracefile,
  "The internal structure of the tree for %d is :\n",
          (long)top_node);
  print_tree_trace(top_node, 1 /*0*/);
  fprintf(tracefile, "\n");
  fprintf(tracefile,
  "The internal structure of the nodes for %d is :\n",
          (long)top_node);
  print_node_trace(top_node);
} /*print_internal_structure*/
